@@ -13,8 +13,8 @@ from boxx import listdir, pathjoin
 import bpy
 import random
 
-from .statu_recover import StatuRecover
 from .utils import encode_inst_id
+from .statu_recover import StatuRecover
 from .node_graph import activate_node_tree, Node
 
 
@@ -25,10 +25,7 @@ class set_inst_material(StatuRecover):
         self.set_attr(bpy.data.worlds[0], "use_nodes", False)
         objs = [obj for obj in bpy.data.objects if obj.type in ("MESH", "CURVE")]
         for obj_idx, obj in enumerate(objs):
-            if "inst_id" in obj:
-                inst_id = obj["inst_id"]
-            else:
-                inst_id = -1  # -1 as default inst_id
+            inst_id = obj.get("inst_id", 0)  # default inst_id is 0
             color = tuple(encode_inst_id.id_to_rgb(inst_id)) + (1,)
 
             material_name = "auto.inst_material." + obj.name
