@@ -15,41 +15,7 @@ import mathutils
 import numpy as np
 
 from .physic_utils import OLD_V0_KEY
-
-
-# we could also define the camera matrix
-# https://blender.stackexchange.com/questions/38009/3x4-camera-matrix-from-blender-camera
-def get_calibration_matrix_K_from_blender(camera):
-    f_in_mm = camera.lens
-    scene = bpy.context.scene
-    resolution_x_in_px = scene.render.resolution_x
-    resolution_y_in_px = scene.render.resolution_y
-    scale = scene.render.resolution_percentage / 100
-    sensor_width_in_mm = camera.sensor_width
-    sensor_height_in_mm = camera.sensor_height
-    pixel_aspect_ratio = scene.render.pixel_aspect_x / scene.render.pixel_aspect_y
-
-    if camera.sensor_fit == "VERTICAL":
-        # the sensor height is fixed (sensor fit is horizontal),
-        # the sensor width is effectively changed with the pixel aspect ratio
-        s_u = resolution_x_in_px * scale / sensor_width_in_mm / pixel_aspect_ratio
-        s_v = resolution_y_in_px * scale / sensor_height_in_mm
-    else:  # 'HORIZONTAL' and 'AUTO'
-        # the sensor width is fixed (sensor fit is horizontal),
-        # the sensor height is effectively changed with the pixel aspect ratio
-        s_u = resolution_x_in_px * scale / sensor_width_in_mm
-        s_v = resolution_y_in_px * scale * pixel_aspect_ratio / sensor_height_in_mm
-
-    # Parameters of intrinsic calibration matrix K
-    alpha_u = f_in_mm * s_u
-    alpha_v = f_in_mm * s_u
-    u_0 = resolution_x_in_px * scale / 2
-    v_0 = resolution_y_in_px * scale / 2
-    skew = 0  # only use rectangular pixels
-
-    K = mathutils.Matrix(((alpha_u, skew, u_0), (0, alpha_v, v_0), (0, 0, 1)))
-
-    return K
+from .camera_utils import get_cam_intrinsic
 
 
 # Returns camera rotation and translation matrices from Blender.
@@ -66,7 +32,7 @@ def get_calibration_matrix_K_from_blender(camera):
 #       - y is down (to align to the actual pixel coordinates
 #         used in digital images)
 #       - right-handed: positive z look-at direction
-def get_3x4_RT_matrix_from_blender(camera):
+def get_4x4_world_to_cam_from_blender(camera):
     # bcam stands for blender camera
     R_bcam2cv = mathutils.Matrix(((1, 0, 0), (0, -1, 0), (0, 0, -1)))
 
@@ -82,31 +48,24 @@ def get_3x4_RT_matrix_from_blender(camera):
     R_world2cv = R_bcam2cv @ R_world2bcam
     T_world2cv = R_bcam2cv @ T_world2bcam
 
-    # put into 3x4 matrix
-    RT = mathutils.Matrix(
+    # put into 4x4 matrix
+    world_to_cam = mathutils.Matrix(
         (
             R_world2cv[0][:] + (T_world2cv[0],),
             R_world2cv[1][:] + (T_world2cv[1],),
             R_world2cv[2][:] + (T_world2cv[2],),
+            (0, 0, 0, 1),
         )
     )
-    return RT
+    return world_to_cam
 
 
-def get_3x4_P_matrix_from_blender(camera):
-    K = get_calibration_matrix_K_from_blender(camera.data)
-    RT = get_3x4_RT_matrix_from_blender(camera)
-    return K * RT
-
-
-def get_K_P_from_blender(camera):
-    K = get_calibration_matrix_K_from_blender(camera.data)
-    RT = get_3x4_RT_matrix_from_blender(camera)
-    RT = np.asarray(RT, dtype=np.float32)
-    world_to_cam = np.append(RT, [[0, 0, 0, 1]], axis=0)
+def get_K_world_to_cam(camera):
+    K = get_cam_intrinsic(camera)
+    world_to_cam = get_4x4_world_to_cam_from_blender(camera)
     return {
         "intrinsic_matrix": np.asarray(K, dtype=np.float32),
-        "world_to_cam": world_to_cam,
+        "world_to_cam": np.asarray(world_to_cam, dtype=np.float32),
     }
 
 
@@ -127,7 +86,7 @@ def get_6d_pose(objs, inst=None, camera=None):
     if camera is None:
         camera = bpy.context.scene.camera
     meta = dict()
-    meta.update(get_K_P_from_blender(camera))
+    meta.update(get_K_world_to_cam(camera))
     meta["cam_matrix_world"] = np.array(camera.matrix_world)
     for key in [
         "inst_ids",
